---
jupyter:
  jupytext:
    notebook_metadata_filter: all,-language_info
    split_at_heading: true
    text_representation:
      extension: .Rmd
      format_name: rmarkdown
      format_version: '1.2'
      jupytext_version: 1.14.1
  kernelspec:
    display_name: Python 3 (ipykernel)
    language: python
    name: python3
---

# A heading


Some text - the text contains punctuation; nevertheless, we get the correct count!

Another line.

```{python}
# This is a long comment.  Comments do not count towards count.
print("These words also do not contribute to the count")
```

More text.

And again.

```{python}
# More comment words
print('More words in a print statement')
```

```{python active="", eval=FALSE}
A raw text cell.  This also does not count to the count, at least, by default.
```

A final text cell.

```{python}
# A final code cell.
```
